<?php
/**
 * This file is part of
 *
 * alaBooking
 *
 * a module for pragmamx (www.pragmamx.org)
 *
 * $Version: 1.2.1 $
 * $Author: André Lachnicht / aLaNiSo / www.alaniso.de $
 * $Date: 2015/11/12  $
 *
 */
defined ( 'mxMainFileLoaded' ) or die ( 'access denied' );

/**
 * alaBooking_admin_setup
 *
 * @package
 *
 * @author A.Lachnicht
 * @access public extends wkaSettings
 */
class alaBooking_admin_setup extends alaBooking_admin {

  /**
   * alaBooking_admin_setup::__construct()
   */
  public function __construct() {
    // Setup ist nur für Systemadministratoren erlaubt!
    if (! MX_IS_SYSADMIN) {
      return mxredirect ( 'modules.php?name=' . $this->_module_name, _GROUPRESTRICTEDAREA );
    }
    
    parent::__construct (); // Ohne Parameter, da sonst Endlos-Rekursiv!
    
    $step = (empty ( $_GET ['step'] )) ? 0 : $_GET ['step'];
    switch (true) {
      case ! mxGetadminPref ( 'radminsuper' ) :
        mxRedirect ( './', _ALABOOKING_ADMINLOGINERROR, 5 );
        break;
      case $step == 1 :
        $this->step_1 ();
        break;
      case $step == 2 :
        $this->step_2 ();
        break;
      default :
        $this->step_0 ();
        break;
    }
  }

  /**
   * alaBooking_admin_setup::step_0()
   *
   * @return
   *
   */
  private function step_0() {
  
  	$qrys = false;
  	$errors = false;
  	$messages = '';
  	$this->_template->assign ( 'errors', $errors );
  	$this->_template->assign ( 'qrys', $qrys );
  	$this->_template->assign ( 'messages', $messages );
  	$this->_template->assign ( 'step', '0' );
  
  	$out = $this->_template->fetch ( 'admin_setup.html' );
  
  	$next_step = 1;
  	$this->admin_setup_page ( $out, $next_step );
  }
  
  /**
   * alaBooking_admin_setup::step_1()
   *
   * @return
   *
   */
  private function step_1() {
    /* Die ben�tigten Dateien includen: */
    if (! file_exists ( PMX_SYSTEM_DIR . DS . 'mx_install.php' )) {
      mxErrorScreen ( 'Install library is missing! <br /><i>' . PMX_SYSTEM_DIR . DS . 'mx_install.php</i>' );
      exit ();
    }
    include_once (PMX_SYSTEM_DIR . DS . 'mx_install.php');
    
    @ini_set ( 'max_execution_time', 0 ); // Wir benötigen Zeit:
    $tables = setupGetTables ();
    
    ob_start ();
    $prefix = $GLOBALS ['prefix'];
    $user_prefix = $GLOBALS ['user_prefix'];
    require (dirname ( dirname ( __FILE__ ) ) . DS . 'core' . DS . 'install.tabledef.php');
    $messages = ob_get_clean ();
    
    $qrys = false;
    if ($messages && preg_match_all ( '#<li>.+</li>#isU', $messages, $matches )) {
      $qrys = $matches [0];
      $messages = str_replace ( $matches [0], '', $messages );
    }
    
    $errors = false;
    if ($messages && preg_match_all ( '#descr:(<b>.+</b>\s*\(\s*mysql\s*[0-9]+\s*\))#isU', $messages, $matches )) {
      $errors = $matches [1];
    }
    
    $this->_template->assign ( 'errors', $errors );
    $this->_template->assign ( 'qrys', $qrys );
    $this->_template->assign ( 'messages', $messages );
    $this->_template->assign ( 'step', '1' );
    
    $out = $this->_template->fetch ( 'admin_setup.html' );
    
    $next_step = 2;
    $this->admin_setup_page ( $out, $next_step );
  }

  /**
   * alaBooking_admin_setup::step_2()
   *
   * @return
   *
   */
  private function step_2() {

    global $alaBooking_version;
    if (! isset ( $this->ref_cfg )) {
      $ref_cfg = load_class ( "Config", $this->_module_name );
    }
    $ref_cfg->setValue ( 'version', $alaBooking_version, $this->_module_name );
    
    return mxRedirect ( PMX_HOME_URL . '/admin.php?op=' . $this->_module_name . '/settings' );
  }

  /**
   * alaBooking_admin_setup::admin_setup_page()
   *
   * @return
   *
   */
  private function admin_setup_page($out, $next_step) {

    $tb = load_class ( 'AdminForm', "adminFormMain" );
    
    $tb->tb_text = _FUNCTIONS;
    $tb->tb_direction = 'right';
    $tb->infobutton = false;
    $tb->tb_pic_heigth = 22;
    $tb->csstoolbar = "toolbar1";
	$tb->cssform = "adminForm";
	$tb->homelink = true;
    $tb->tb_show = 'bottom'; // Buttonleiste unten
    $tb->acceptbutton = false;
    
    // $tb->addToolbar("save");
    $tb->addToolbarLink ( "cpanel", "admin.php?op=" . $this->_module_name );
    $tb->addToolbarLink ( "next", "admin.php?op=" . $this->_module_name . "/setup&step=" . $next_step );
    
    // /* Form elements */
    // $tb->addFieldSet("head", "Setup", "", false);
    // Den aufbereiteten HTML-Code ausgeben:
    $tb->add ( "", "html", $out );
    
    $form = $tb->Show ();
    $info2 = $this->_module_name;
    
    $this->adminpage ( $form );
  }
}

?>